/**
   This program magnifies a PPM image to twice its original dimensions.
   For every pixel in the original image, a square block of four
   pixels is written to the magnified image. Each pixel in the
   square block is the average of the original pixel and one of
   its adjacent neighbors.
*/
import framebuffer.*;
import java.awt.Color;

public class MagnifyPPM_ver2
{
   public static void main(String[] args)
   {
      // Check for a file name on the command line.
      if ( 0 == args.length )
      {
         System.err.println("Usage: java MagnifyPPM_ver2 <PPM-file-name>");
         System.exit(-1);
      }
      // the input image
      FrameBuffer fb1 = new FrameBuffer( args[0] );
      // the output image
      FrameBuffer fb2 = new FrameBuffer(2*fb1.getWidthFB(), 2*fb1.getHeightFB());

      for (int y = 0; y < fb1.getHeightFB(); y++)
      {
         for (int x = 0; x < fb1.getWidthFB(); x++)
         {
            Color c1 = fb1.getPixelFB(x+0, y+0);
            Color c2 = fb1.getPixelFB(x+0, y+1);
            Color c3 = fb1.getPixelFB(x+1, y+0);
            Color c4 = fb1.getPixelFB(x+1, y+1);

            int r2 = (int)Math.round( (c1.getRed()   + c2.getRed()  )/2.0 );
            int g2 = (int)Math.round( (c1.getGreen() + c2.getGreen())/2.0 );
            int b2 = (int)Math.round( (c1.getBlue()  + c2.getBlue() )/2.0 );

            int r3 = (int)Math.round( (c1.getRed()   + c3.getRed()  )/2.0 );
            int g3 = (int)Math.round( (c1.getGreen() + c3.getGreen())/2.0 );
            int b3 = (int)Math.round( (c1.getBlue()  + c3.getBlue() )/2.0 );

            int r4 = (int)Math.round( (c1.getRed()   + c4.getRed()  )/2.0 );
            int g4 = (int)Math.round( (c1.getGreen() + c4.getGreen())/2.0 );
            int b4 = (int)Math.round( (c1.getBlue()  + c4.getBlue() )/2.0 );

            fb2.setPixelFB( 2*x+0, 2*y+0, c1 );
            fb2.setPixelFB( 2*x+0, 2*y+1, new Color(r2, g2, b2) );
            fb2.setPixelFB( 2*x+1, 2*y+0, new Color(r3, g3, b3) );
            fb2.setPixelFB( 2*x+1, 2*y+1, new Color(r4, g4, b4) );
         }
      }
      String baseName = args[0].substring(0, args[0].lastIndexOf("."));
      String savedFileName = baseName + "_magnify_ver2" + ".ppm";
      fb2.dumpFB2File( savedFileName );
   }
}
